==> pnotify-5.1.2.jar: META-INF/resources/webjars/pnotify/5.1.2/CHANGELOG.md <==
# Change Log

All notable changes to this project will be documented in this file.
See [Conventional Commits](https://conventionalcommits.org) for commit guidelines.

## [5.1.2](https://github.com/sciactive/pnotify/compare/v5.1.1...v5.1.2) (2020-04-29)



## 5.1.1 (2020-04-27)

**Note:** Version bump only for package pnotify





## [5.1.1](https://github.com/sciactive/pnotify/compare/v5.1.0...v5.1.1) (2020-04-27)


### Bug Fixes

* font awesome fix changing from fa icon ([33b3733](https://github.com/sciactive/pnotify/commit/33b3733143628a34bba39f5ef030bc5746529119))
* font awesome icon change after the first change ([1d9239d](https://github.com/sciactive/pnotify/commit/1d9239df5113059d0fa3cff5efc6a6d5455003f7)), closes [#391](https://github.com/sciactive/pnotify/issues/391)
* remove erroneous fa5 fix file from fa5 module ([642facf](https://github.com/sciactive/pnotify/commit/642facf218d7f71bfb3cf57ceff56709b0c58beb))
* reverse colors on countdown bar ([2ebc862](https://github.com/sciactive/pnotify/commit/2ebc862ab920936ac4ffa13df23dcaddf2addc1c)), closes [#390](https://github.com/sciactive/pnotify/issues/390)
* run build js through babel ([edd8ce7](https://github.com/sciactive/pnotify/commit/edd8ce7f5e8ea008114e178dc5f0a9b08b9c7d5e)), closes [#389](https://github.com/sciactive/pnotify/issues/389)



# 5.1.0 (2020-04-21)





# [5.1.0](https://github.com/sciactive/pnotify/compare/v5.0.1...v5.1.0) (2020-04-21)


### Features

* **core:** add type declaration core ([be78dbf](https://github.com/sciactive/pnotify/commit/be78dbf253f8cdf0ba9c921da452d8cca45651bd)), closes [#366](https://github.com/sciactive/pnotify/issues/366)
* add almost working types to modules ([82c5ce3](https://github.com/sciactive/pnotify/commit/82c5ce391dfc426ab503dd39653373325c3c4c60))
* complete types for modules and core ([9b04b0f](https://github.com/sciactive/pnotify/commit/9b04b0fc76da7f9efcff7887d85e3cdfbcd66db1)), closes [#366](https://github.com/sciactive/pnotify/issues/366)



## 5.0.1 (2020-04-18)





## [5.0.1](https://github.com/sciactive/pnotify/compare/v5.0.0...v5.0.1) (2020-04-18)


### Bug Fixes

* correct runtime dependencies ([65fe80f](https://github.com/sciactive/pnotify/commit/65fe80fb18f7bd2a3d1d6d1540eae617b21925b6))



# 5.0.0 (2020-04-17)





# [5.0.0](https://github.com/sciactive/pnotify/compare/v5.0.0-alpha.7...v5.0.0) (2020-04-17)


### Bug Fixes

* prevent unnecessary scrollbars on Firefox ([d0937c3](https://github.com/sciactive/pnotify/commit/d0937c329e62cfd786ceb451635aeacf05adf2cb))


### Features

* change "stick" labels to "pin" instead ([1a60040](https://github.com/sciactive/pnotify/commit/1a60040cec4e84f71e004a04a9959b2a4045b225))
* finish countdown module doc, and remove showTime ([f93efc5](https://github.com/sciactive/pnotify/commit/f93efc5872bc475ce5b0949955c799b4a1f21c71))
* new countdown module to show countdown display ([67b56ba](https://github.com/sciactive/pnotify/commit/67b56ba92bc171aaf74933d18c89cd26f94fc124))





# [5.0.0-alpha.7](https://github.com/sciactive/pnotify/compare/v5.0.0-alpha.6...v5.0.0-alpha.7) (2020-04-03)


### Features

* add infinite timer support. closes [#385](https://github.com/sciactive/pnotify/issues/385) ([92ae3ef](https://github.com/sciactive/pnotify/commit/92ae3efeb48af2a68ff0dca8e3ce8a2afde4b0b7))



## 4.0.1 (2020-03-06)



# 5.0.0-alpha.6 (2020-02-29)





# 5.0.0-alpha.6 (2020-02-29)



# 5.0.0-alpha.5 (2020-02-28)



# 5.0.0-alpha.4 (2020-02-28)



# 5.0.0-alpha.3 (2020-02-20)



# 5.0.0-alpha.2 (2020-02-20)



# 5.0.0-alpha.1 (2020-02-20)



# 4.0.0 (2019-04-24)



# 4.0.0-beta.2 (2018-12-05)



# 4.0.0-beta.1 (2018-11-24)



# 4.0.0-alpha.4 (2018-05-17)



# 4.0.0-alpha.3 (2018-04-24)



# 4.0.0-alpha.2 (2018-02-14)



# 4.0.0-alpha.1 (2018-01-27)



## 3.2.1 (2017-07-31)



# 3.2.0 (2017-04-24)



## 3.0.1 (2017-04-21)



# 3.0.0 (2015-12-21)



# 2.1.0 (2015-09-03)



## 2.0.1 (2014-05-13)



# 2.0.0 (2014-04-10)



## 1.3.1 (2014-03-13)



# 1.3.0 (2014-03-13)


### Reverts

* Revert "Clicking the "Last" history button should open the most recent notice, not only the first notice ever opened. In addition, when using the "push": "top" stack option, the most recent notice is at the opposite end of the array so this should be accounted for." ([b2e2cbd](https://github.com/sciactive/pnotify/commit/b2e2cbd2b772ba16cb2066fb41b5f03f02caa0f7))
* Revert "Clicking the "All" history button should open ALL notices, not just the first notice displayed." ([1e4badf](https://github.com/sciactive/pnotify/commit/1e4badfd65c0a5d5638a2ea8f73de1057e3c3ca5))



# 1.2.0 (2012-06-16)



## 1.1.1 (2012-04-19)



# 1.1.0 (2011-12-22)



## 1.0.2 (2011-09-01)



## 1.0.1 (2010-07-23)



# 1.0.0 (2010-06-15)

==> pnotify-5.2.0.jar: META-INF/resources/webjars/pnotify/5.2.0/CHANGELOG.md <==
# Change Log

All notable changes to this project will be documented in this file.
See [Conventional Commits](https://conventionalcommits.org) for commit guidelines.

# [5.2.0](https://github.com/sciactive/pnotify/compare/v5.1.2...v5.2.0) (2020-11-06)


### Bug Fixes

* correct color on custom icons in Bright Theme ([a985f98](https://github.com/sciactive/pnotify/commit/a985f98db5ca6c5a98086dd02db724b0c3d12bc7))
* fix a commit dependency issue ([c086a88](https://github.com/sciactive/pnotify/commit/c086a881aba00120e56eccfae662462e7815dc08))
* fix an issue with Countdown module not updating bar ([860ef8e](https://github.com/sciactive/pnotify/commit/860ef8ed0d7fbfbc095a27d0d3637ec7455bdda7))
* fix Angeler theme Confirm module placement ([51f3e44](https://github.com/sciactive/pnotify/commit/51f3e44ac73c30047a84d62065aea36c968e8ab9))
* fix countdown bar appearance in Angeler theme ([ec5d7f1](https://github.com/sciactive/pnotify/commit/ec5d7f13b31f81fda7cea57ef1baa67f7c99f8f2))
* fix positioning of fallback desktop notice in modalish stacks ([66ea908](https://github.com/sciactive/pnotify/commit/66ea9085292ad16ecf2035ee797c492413f21189))
* fix some styling issues on masking and immediate close ([6c3bfbc](https://github.com/sciactive/pnotify/commit/6c3bfbcf4cd8e2b75c5a3e6d0fb4f73221b00a17))


### Features

* add Angeler theme ([d9f9721](https://github.com/sciactive/pnotify/commit/d9f972187d4c7f1b5d8b448c3b005aebdb934e72))
* add new Paginate module for navigating notices in the stack ([92fda56](https://github.com/sciactive/pnotify/commit/92fda563a269415271f0be5dc6cc82b0a8e7ae04))
* add Roboto font support to Material style ([e7e09c3](https://github.com/sciactive/pnotify/commit/e7e09c3e2316722172f254111babd1cf45b66d96))
* add stack swapping, stack events, and notice open/close promises ([f542597](https://github.com/sciactive/pnotify/commit/f542597a4e2b90334997fb2826f735d7f865d541))
* let notices be placed in the normal flow in unpositioned stacks ([cc7fec3](https://github.com/sciactive/pnotify/commit/cc7fec3ad714b488dc21138a5a231f169bb9c07b))



## 5.1.2 (2020-04-29)





## [5.1.2](https://github.com/sciactive/pnotify/compare/v5.1.1...v5.1.2) (2020-04-29)



## 5.1.1 (2020-04-27)

**Note:** Version bump only for package pnotify





## [5.1.1](https://github.com/sciactive/pnotify/compare/v5.1.0...v5.1.1) (2020-04-27)


### Bug Fixes

* font awesome fix changing from fa icon ([33b3733](https://github.com/sciactive/pnotify/commit/33b3733143628a34bba39f5ef030bc5746529119))
* font awesome icon change after the first change ([1d9239d](https://github.com/sciactive/pnotify/commit/1d9239df5113059d0fa3cff5efc6a6d5455003f7)), closes [#391](https://github.com/sciactive/pnotify/issues/391)
* remove erroneous fa5 fix file from fa5 module ([642facf](https://github.com/sciactive/pnotify/commit/642facf218d7f71bfb3cf57ceff56709b0c58beb))
* reverse colors on countdown bar ([2ebc862](https://github.com/sciactive/pnotify/commit/2ebc862ab920936ac4ffa13df23dcaddf2addc1c)), closes [#390](https://github.com/sciactive/pnotify/issues/390)
* run build js through babel ([edd8ce7](https://github.com/sciactive/pnotify/commit/edd8ce7f5e8ea008114e178dc5f0a9b08b9c7d5e)), closes [#389](https://github.com/sciactive/pnotify/issues/389)



# 5.1.0 (2020-04-21)





# [5.1.0](https://github.com/sciactive/pnotify/compare/v5.0.1...v5.1.0) (2020-04-21)


### Features

* **core:** add type declaration core ([be78dbf](https://github.com/sciactive/pnotify/commit/be78dbf253f8cdf0ba9c921da452d8cca45651bd)), closes [#366](https://github.com/sciactive/pnotify/issues/366)
* add almost working types to modules ([82c5ce3](https://github.com/sciactive/pnotify/commit/82c5ce391dfc426ab503dd39653373325c3c4c60))
* complete types for modules and core ([9b04b0f](https://github.com/sciactive/pnotify/commit/9b04b0fc76da7f9efcff7887d85e3cdfbcd66db1)), closes [#366](https://github.com/sciactive/pnotify/issues/366)



## 5.0.1 (2020-04-18)





## [5.0.1](https://github.com/sciactive/pnotify/compare/v5.0.0...v5.0.1) (2020-04-18)


### Bug Fixes

* correct runtime dependencies ([65fe80f](https://github.com/sciactive/pnotify/commit/65fe80fb18f7bd2a3d1d6d1540eae617b21925b6))



# 5.0.0 (2020-04-17)





# [5.0.0](https://github.com/sciactive/pnotify/compare/v5.0.0-alpha.7...v5.0.0) (2020-04-17)


### Bug Fixes

* prevent unnecessary scrollbars on Firefox ([d0937c3](https://github.com/sciactive/pnotify/commit/d0937c329e62cfd786ceb451635aeacf05adf2cb))


### Features

* change "stick" labels to "pin" instead ([1a60040](https://github.com/sciactive/pnotify/commit/1a60040cec4e84f71e004a04a9959b2a4045b225))
* finish countdown module doc, and remove showTime ([f93efc5](https://github.com/sciactive/pnotify/commit/f93efc5872bc475ce5b0949955c799b4a1f21c71))
* new countdown module to show countdown display ([67b56ba](https://github.com/sciactive/pnotify/commit/67b56ba92bc171aaf74933d18c89cd26f94fc124))





# [5.0.0-alpha.7](https://github.com/sciactive/pnotify/compare/v5.0.0-alpha.6...v5.0.0-alpha.7) (2020-04-03)


### Features

* add infinite timer support. closes [#385](https://github.com/sciactive/pnotify/issues/385) ([92ae3ef](https://github.com/sciactive/pnotify/commit/92ae3efeb48af2a68ff0dca8e3ce8a2afde4b0b7))



## 4.0.1 (2020-03-06)



# 5.0.0-alpha.6 (2020-02-29)





# 5.0.0-alpha.6 (2020-02-29)



# 5.0.0-alpha.5 (2020-02-28)



# 5.0.0-alpha.4 (2020-02-28)



# 5.0.0-alpha.3 (2020-02-20)



# 5.0.0-alpha.2 (2020-02-20)



# 5.0.0-alpha.1 (2020-02-20)



# 4.0.0 (2019-04-24)



# 4.0.0-beta.2 (2018-12-05)



# 4.0.0-beta.1 (2018-11-24)



# 4.0.0-alpha.4 (2018-05-17)



# 4.0.0-alpha.3 (2018-04-24)



# 4.0.0-alpha.2 (2018-02-14)



# 4.0.0-alpha.1 (2018-01-27)



## 3.2.1 (2017-07-31)



# 3.2.0 (2017-04-24)



## 3.0.1 (2017-04-21)



# 3.0.0 (2015-12-21)



# 2.1.0 (2015-09-03)



## 2.0.1 (2014-05-13)



# 2.0.0 (2014-04-10)



## 1.3.1 (2014-03-13)



# 1.3.0 (2014-03-13)


### Reverts

* Revert "Clicking the "Last" history button should open the most recent notice, not only the first notice ever opened. In addition, when using the "push": "top" stack option, the most recent notice is at the opposite end of the array so this should be accounted for." ([b2e2cbd](https://github.com/sciactive/pnotify/commit/b2e2cbd2b772ba16cb2066fb41b5f03f02caa0f7))
* Revert "Clicking the "All" history button should open ALL notices, not just the first notice displayed." ([1e4badf](https://github.com/sciactive/pnotify/commit/1e4badfd65c0a5d5638a2ea8f73de1057e3c3ca5))



# 1.2.0 (2012-06-16)



## 1.1.1 (2012-04-19)



# 1.1.0 (2011-12-22)



## 1.0.2 (2011-09-01)



## 1.0.1 (2010-07-23)



# 1.0.0 (2010-06-15)
